==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/ad/DisplayCpcChainSolutionDetail.java <==
package eleme.openapi.sdk.api.entity.ad;

import java.util.*;
public class DisplayCpcChainSolutionDetail{

    /**
     * 计划id
     */
    private Long id;
    public Long getId() {
        return id;
    }
    public void setId(Long id) {
        this.id = id;
    }
    
    /**
     * 投放计划
     */
    private String title;
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    
    /**
     * 每日预算
     */
    private String budget;
    public String getBudget() {
        return budget;
    }
    public void setBudget(String budget) {
        this.budget = budget;
    }
    
    /**
     * 是否长期
     */
    private Boolean longTerm;
    public Boolean getLongTerm() {
        return longTerm;
    }
    public void setLongTerm(Boolean longTerm) {
        this.longTerm = longTerm;
    }
    
    /**
     * 计划状态
     */
    private String state;
    public String getState() {
        return state;
    }
    public void setState(String state) {
        this.state = state;
    }
    
    /**
     * 是否启动自定义投放时段
     */
    private Boolean isAutoLaunch;
    public Boolean getIsAutoLaunch() {
        return isAutoLaunch;
    }
    public void setIsAutoLaunch(Boolean isAutoLaunch) {
        this.isAutoLaunch = isAutoLaunch;
    }
    
    /**
     * 工作日投放时段
     */
    private List<String> launchHoursHalfList;
    public List<String> getLaunchHoursHalfList() {
        return launchHoursHalfList;
    }
    public void setLaunchHoursHalfList(List<String> launchHoursHalfList) {
        this.launchHoursHalfList = launchHoursHalfList;
    }
    
    /**
     * 是否区分周末投放时段
     */
    private Boolean diffWeekend;
    public Boolean getDiffWeekend() {
        return diffWeekend;
    }
    public void setDiffWeekend(Boolean diffWeekend) {
        this.diffWeekend = diffWeekend;
    }
    
    /**
     * 周末投放时段
     */
    private List<String> weekEndLaunchHoursHalfList;
    public List<String> getWeekEndLaunchHoursHalfList() {
        return weekEndLaunchHoursHalfList;
    }
    public void setWeekEndLaunchHoursHalfList(List<String> weekEndLaunchHoursHalfList) {
        this.weekEndLaunchHoursHalfList = weekEndLaunchHoursHalfList;
    }
    
    /**
     * 单元明细
     */
    private List<DisplayAdGroupResult> adgroupList;
    public List<DisplayAdGroupResult> getAdgroupList() {
        return adgroupList;
    }
    public void setAdgroupList(List<DisplayAdGroupResult> adgroupList) {
        this.adgroupList = adgroupList;
    }
    
    /**
     * 定向出价明细
     */
    private List<DisplayTargetResult> targetList;
    public List<DisplayTargetResult> getTargetList() {
        return targetList;
    }
    public void setTargetList(List<DisplayTargetResult> targetList) {
        this.targetList = targetList;
    }
    
    /**
     * 开始时间
     */
    private String startTime;
    public String getStartTime() {
        return startTime;
    }
    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }
    
    /**
     * 结束时间
     */
    private String endTime;
    public String getEndTime() {
        return endTime;
    }
    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/ad/DisplayCpcChainSolutionDetail.java <==
package eleme.openapi.sdk.api.entity.ad;

import eleme.openapi.sdk.api.enumeration.ad.*;
import eleme.openapi.sdk.api.entity.ad.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class DisplayCpcChainSolutionDetail{

    /**
     * 计划id
     */
    private Long id;
    public Long getId() {
        return id;
    }
    public void setId(Long id) {
        this.id = id;
    }
    
    /**
     * 投放计划
     */
    private String title;
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    
    /**
     * 每日预算
     */
    private String budget;
    public String getBudget() {
        return budget;
    }
    public void setBudget(String budget) {
        this.budget = budget;
    }
    
    /**
     * 是否长期
     */
    private Boolean longTerm;
    public Boolean getLongTerm() {
        return longTerm;
    }
    public void setLongTerm(Boolean longTerm) {
        this.longTerm = longTerm;
    }
    
    /**
     * 计划状态
     */
    private String state;
    public String getState() {
        return state;
    }
    public void setState(String state) {
        this.state = state;
    }
    
    /**
     * 是否启动自定义投放时段
     */
    private Boolean isAutoLaunch;
    public Boolean getIsAutoLaunch() {
        return isAutoLaunch;
    }
    public void setIsAutoLaunch(Boolean isAutoLaunch) {
        this.isAutoLaunch = isAutoLaunch;
    }
    
    /**
     * 工作日投放时段
     */
    private List<String> launchHoursHalfList;
    public List<String> getLaunchHoursHalfList() {
        return launchHoursHalfList;
    }
    public void setLaunchHoursHalfList(List<String> launchHoursHalfList) {
        this.launchHoursHalfList = launchHoursHalfList;
    }
    
    /**
     * 是否区分周末投放时段
     */
    private Boolean diffWeekend;
    public Boolean getDiffWeekend() {
        return diffWeekend;
    }
    public void setDiffWeekend(Boolean diffWeekend) {
        this.diffWeekend = diffWeekend;
    }
    
    /**
     * 周末投放时段
     */
    private List<String> weekEndLaunchHoursHalfList;
    public List<String> getWeekEndLaunchHoursHalfList() {
        return weekEndLaunchHoursHalfList;
    }
    public void setWeekEndLaunchHoursHalfList(List<String> weekEndLaunchHoursHalfList) {
        this.weekEndLaunchHoursHalfList = weekEndLaunchHoursHalfList;
    }
    
    /**
     * 单元明细
     */
    private List<DisplayAdGroupResult> adgroupList;
    public List<DisplayAdGroupResult> getAdgroupList() {
        return adgroupList;
    }
    public void setAdgroupList(List<DisplayAdGroupResult> adgroupList) {
        this.adgroupList = adgroupList;
    }
    
    /**
     * 定向出价明细
     */
    private List<DisplayTargetResult> targetList;
    public List<DisplayTargetResult> getTargetList() {
        return targetList;
    }
    public void setTargetList(List<DisplayTargetResult> targetList) {
        this.targetList = targetList;
    }
    
    /**
     * 开始时间
     */
    private String startTime;
    public String getStartTime() {
        return startTime;
    }
    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }
    
    /**
     * 结束时间
     */
    private String endTime;
    public String getEndTime() {
        return endTime;
    }
    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
    
}
